# Changelog

## [Unreleased]

## [0.0.27] - 2024-12-12
* Fixed extraction of Gravatar username by @soxoj in https://github.com/soxoj/socid-extractor/pull/178
* Added SOWEL techniques by @soxoj in https://github.com/soxoj/socid-extractor/pull/176
* Bump pytest from 7.3.0 to 7.4.2 by @dependabot in https://github.com/soxoj/socid-extractor/pull/167
* Update beautifulsoup4 requirement from ~=4.12.2 to ~=4.12.3 by @dependabot in https://github.com/soxoj/socid-extractor/pull/175
* Bump pytest-xdist from 3.3.1 to 3.5.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/172
* Bump pytest from 7.4.2 to 7.4.4 by @dependabot in https://github.com/soxoj/socid-extractor/pull/174
* Bump pytest-rerunfailures from 12.0 to 13.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/173
* Bump pytest from 7.4.4 to 8.3.4 by @dependabot in https://github.com/soxoj/socid-extractor/pull/182
* Bump pytest-xdist from 3.5.0 to 3.6.1 by @dependabot in https://github.com/soxoj/socid-extractor/pull/181
* Bump pytest-rerunfailures from 13.0 to 15.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/180

**Full Changelog**: https://github.com/soxoj/socid-extractor/compare/v0.0.26...v0.0.27

## [0.0.26] - 2023-10-11
* Update python-package.yml by @soxoj in https://github.com/soxoj/socid-extractor/pull/160
* Update README.md by @soxoj in https://github.com/soxoj/socid-extractor/pull/161
* Repairing most of the tests, updating schemes.py accordingly by @MeowyPouncer in https://github.com/soxoj/socid-extractor/pull/162
* Bump pytest-xdist from 2.5.0 to 3.3.1 by @dependabot in https://github.com/soxoj/socid-extractor/pull/164
* Bump pytest-rerunfailures from 10.2 to 12.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/163
* Bump pytest from 7.1.2 to 7.3.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/151
* Update beautifulsoup4 requirement from ~=4.11.1 to ~=4.12.2 by @dependabot in https://github.com/soxoj/socid-extractor/pull/150

**Full Changelog**: https://github.com/soxoj/socid-extractor/compare/v0.0.25...v0.0.26

## [0.0.25] - 2023-07-24
* Added memory.lol by @soxoj in https://github.com/soxoj/socid-extractor/pull/156

**Full Changelog**: https://github.com/soxoj/socid-extractor/compare/v0.0.24...v0.0.25

## [0.0.24] - 2023-07-07
* Added aparat.com, added list of methods by @soxoj in https://github.com/soxoj/socid-extractor/pull/116
* Bump pytest from 6.2.5 to 7.1.2 by @dependabot in https://github.com/soxoj/socid-extractor/pull/126
* Update beautifulsoup4 requirement from ~=4.10.0 to ~=4.11.1 by @dependabot in https://github.com/soxoj/socid-extractor/pull/125
* Some tests and TikTok parsing fixed by @soxoj in https://github.com/soxoj/socid-extractor/pull/127
* Added UnstoppableDomains parser for Maigret by @soxoj in https://github.com/soxoj/socid-extractor/pull/154

**Full Changelog**: https://github.com/soxoj/socid-extractor/compare/v0.0.23...v0.0.24

## [0.0.23] - 2022-01-02
* Accelerated module import time by @soxoj in https://github.com/soxoj/socid-extractor/pull/104
* Reddit, Twitch and Last.fm fixes by @soxoj in https://github.com/soxoj/socid-extractor/pull/105
* September update by @cyb3rk0tik in https://github.com/soxoj/socid-extractor/pull/106
* Bump pytest-xdist from 2.2.1 to 2.4.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/107
* Bump pytest-rerunfailures from 9.1.1 to 10.2 by @dependabot in https://github.com/soxoj/socid-extractor/pull/108
* Tests fixes by @soxoj in https://github.com/soxoj/socid-extractor/pull/109
* Fixes by @soxoj in https://github.com/soxoj/socid-extractor/pull/110
* Bump pytest-xdist from 2.4.0 to 2.5.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/111
* Added VK foaf page check by @soxoj in https://github.com/soxoj/socid-extractor/pull/113
* Update beautifulsoup4 requirement from ~=4.9.1 to ~=4.10.0 by @dependabot in https://github.com/soxoj/socid-extractor/pull/114

**Full Changelog**: https://github.com/soxoj/socid-extractor/compare/v0.0.22...v0.0.23

## [0.0.22] - 2021-06-23
* added Tinder, Disqus API and ifunny.co
* fixed Twitter scraping from CLI
* extended My.Mail.ru extractor
* improved tests

## [0.0.21] - 2021-05-31
* added ICQ, Pastebin, Periscope, Paypal, Imgur API
* improved Google Docs extractors
* fixed Yandex service processing
* added cookiejar support

## [0.0.20] - 2021-05-15
* fixed email-to-username postprocessor bug
* added yandex-username-to-email postprocessor

## [0.0.19] - 2021-05-12
* non-json transforms
* added Weibo and Trello
* added username-from-email extractor
* added Yelp

## [0.0.18] - 2021-05-04
* fixed and improved Behance
* improved image links extraction

## [0.0.17] - 2021-04-18
* fixed Yandex, Telegram & Facebook

## [0.0.16] - 2021-03-30
* removed account matching functionality and heavy dependencies
* improved Gravatar

## [0.0.15] - 2021-03-21
* added URLs mutation logic
* added Google Docs API
* added uID.me and uCoz sites

## [0.0.14] - 2021-03-18
* improved StackOverflow
* added Disqus API and Yandex.O

## [0.0.13] - 2021-03-14
* added Gravatar hash extractors
* improved Facebook parsing
* fixed tests

## [0.0.12] - 2021-02-22
* updated requirements

## [0.0.11] - 2021-02-18
* added Linktree, Spotify
* added Twitch, Launchpad
* added Last.fm, Ask.fm
* improved Steam, Habrahabr
* fixed tests

## [0.0.10] - 2021-02-15
* updated setup requirements
* improved Twitter extractor

## [0.0.9] - 2021-02-05
* added Yandex.Music API, 1x.com
* improved errors catching

## [0.0.8] - 2021-02-03
* added Yandex.Messenger

## [0.0.7] - 2021-01-31
* added Tumblr (default theme) and Yandex.Market

## [0.0.6] - 2021-01-31
* updated Yandex services extractors (again)

## [0.0.5] - 2021-01-31
* updated Yandex services extractors

## [0.0.4] - 2021-01-16
* actualized Vimeo and VK

## [0.0.3] - 2021-01-15
* actualized Twitter
